#!/bin/csh -f
#
# build-functions.csh: build the S2PLOT function demo programs
#
# ==================================================================
# S2PLOT is freely available for non-commercial and educational use,
# however, it is not public-domain software. The programming library
# and documentation may not be redistributed or sub-licensed in any
# form without permission from Swinburne University of
# Technology. The programming library and sample codes are provided
# without warranty.
#
# We would appreciate it if research outcomes using S2PLOT would
# provide the following acknowledgement:
#
# "Three-dimensional visualisation was conducted with the S2PLOT
# progamming library"
#
# and a reference to 
#
# D.G.Barnes, C.J.Fluke, P.D.Bourke & O.T.Parry, 2006, Publications
# of the Astronomical Society of Australia, 23(2), 82-93.
#
# S2PLOT development was funded through the Researcher Developer
# Grant Scheme at Swinburne University of Technology.
# ==================================================================
#
# original version: David Barnes, early 2007
#
# $Id: build-functions.csh 5268 2008-09-02 22:59:16Z dbarnes $

if (!(${?S2PATH})) then
  echo "S2PATH environment variable MUST be set ... please fix and retry."
  exit(-1);
endif
if (! -d $S2PATH || ! -e ${S2PATH}/s2plot.csh) then
  echo "S2PATH is set but invalid: ${S2PATH} ... please fix and retry."
  exit(-1);
endif
source ${S2PATH}/s2plot.csh
if ($status) then
  exit(-1)
endif

set thisdir=$cwd
if ($thisdir != $S2PATH) then
  echo "You must be in directory ${S2PATH} to run build-samples.csh script."
  echo "(or if you are, try removing any trailing '/' in your S2PATH setting)"
  exit(-1);
endif

if ($S2SHARED == yes) then
  echo "Using shared S2PLOT library for ${S2KERNEL}."
else
  echo "Using static S2PLOT library for ${S2KERNEL}."
endif

if (! -d $S2KERNEL) then
  echo "Directory ${S2KERNEL} does not exist!  Cannot build!  Try running"
  echo "build-lib.csh script first, or re-installing your distribution."
  exit(-1);
endif

if (! -e ${S2KERNEL}/${S2LIBNAME}) then
  echo "Library ${S2LIBNAME} is missing!  Cannot build!  Try running "
  echo "build-lib.csh script first, or re-installing your distribution."
  exit(-1);
endif

echo "Entering target directory ${S2KERNEL}."
cd $S2KERNEL

set S2OBJECTS=""

foreach targetext (`cd ../functions && ls *.c`)
  set target=`echo $targetext | sed -e 's/\.c//g'`
  echo "Compiling function demonstration program ($target) ..."
  $S2COMPILER ../functions/${target}.c
  set S2OBJECTS="${S2OBJECTS} ${target}.o"
  echo "Linking function demonstration program (${target}) ..."
  $S2CLINKER -o ${target} ${target}.o -L. -L/usr/lib ${S2LINKS} ${MLLINKS} ${SWLINKS} ${GLLINKS} -L${S2X11PATH}/lib -L${S2X11PATH}/lib${S2LBITS} ${S2FORMSLINK} -lXpm -lX11 ${IMATH} -lm ${XLINKPATH}
  if ($S2KERNEL == darwin && $S2SHARED == yes) then
    echo "Modifying dynamic library path ..."
    install_name_tool -change ${S2PATH}/${S2KERNEL}/${S2LIBNAME} @executable_path/${S2LIBNAME} ${target}
  endif
end

echo Removing objects ...
rm -rf $S2OBJECTS

echo Done!


